CopyWith class
Classes annotated with @CopyWith() will generate a copyWith() method
- Annotations
-
- @Target.new({TargetKind.classType})
Constructors
Properties
- asExtension → bool?
-
will generate the as an extension
final
- constructor → String?
-
The name of the constructor that should be used for copyWith()
Example:
CopyWith.fromJson(Map<String, Object?> json)will befromJson.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → String?
-
The suffix is applied to the generated mixin
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited