inCopyWith property

bool inCopyWith
final

if false, the field will not be included in the copyWith() method effectively resetting the field to the default value with each copyWith() call

defaults to true

Implementation

final bool inCopyWith;