unmodifiable property

bool unmodifiable
final

if true, the field will not be changeable in the copyWith() method preserving the first value that was ever set.

This is useful for fields that contain generated IDs.

defaults to false

Implementation

final bool unmodifiable;