EqualityKey constructor
It is generally discouraged to only disable one and not the other.
But who am I to take this option from you.
Implementation
const EqualityKey({
bool? inHash,
bool? inEquals,
}) : inHash = inHash ?? true,
inEquals = inEquals ?? true;