EqualityKey constructor

const EqualityKey({
  1. bool? inHash,
  2. bool? inEquals,
})

Use EqualityKey.exclude

It is generally discouraged to only disable one and not the other.

But who am I to take this option from you.

Implementation

const EqualityKey({
  bool? inHash,
  bool? inEquals,
})  : inHash = inHash ?? true,
      inEquals = inEquals ?? true;